%define name radeon-firmware
%define version 20210423
%define release %mkrel 1

Summary: ATI/AMD Radeon firmware files
Name:	 %{name}
Version: %{version}
Release: %{release}
# extracted from git://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git
# all files in radeon/ and amdgpu/ dirs, LICENSE.{radeon,amdgpu} and WHENCE (license for some files)
# git archive --prefix=radeon-firmware/ HEAD radeon LICENSE.radeon amdgpu LICENSE.amdgpu WHENCE | xz > radeon-firmware-20200721.tar.xz
Source0: %{name}-%{version}.tar.xz
License: Freeware
Group:	 System/Kernel and hardware
Url:	 http://ati.amd.com/
BuildArch: noarch
Obsoletes: radeon-rlc-firmware
Conflicts: kernel-firmware < 20120219-1
Conflicts: kernel-firmware-nonfree < 20120219-1

%description
Firmware files for AMD/ATI Radeon graphics cards.

This package contains all the firmware files (including RLC) for the
following Radeon series: R100, R200, R300, R400, R500, R600, R700,
Evergreen, Fusion, Northern Islands, Southern Islands, Cayman, Llano,
Trinity, Oland, Hainan, Bonaire, Kabini, Kaveri, Hawaii, Mullins.
It also have firmwares for amdgpu: Carrizo, Fiji, Stoney, Tonga, Polaris,
Vega, Raven(2), Picasso, Navi, Sienna Cichlid, Green Sardine, Arcturus.

%prep
%setup -q -n %{name}-%{version}

cat WHENCE | while read line; do
	set -e
	case "$line" in
	"Driver: "*)
		driver="${line#Driver: }"
		free=
		files=
		license=
		;;
	"File: "*)
		file="${line#File: }"
		file=$(echo $file | tr -d '"' | tr ' ' '^')
		files="$files ${file}"
		;;
	"Source: "*)
		free=1
		;;
	"License: "*|"Licence: "*)
		license="${line#Licen?e: }"
		case "$license" in
		*"Allegedly"*|*"no source visible"*)
			;;
		*"GPL"*)
			free=1
			;;
		esac
		;;
	*"Advanced Micro Devices, Inc.")
		free=1
		;;
	"Original licence information: None")
		free=
		;;
	"------"*)
		if [ -n "$free" ]; then
			for file in $files; do
				file="$(echo $file | tr '^' ' ')"
				rm -f "$file"
			done
		fi
		;;
	esac
done

%build

%install
rm -rf %{buildroot}
install -d %{buildroot}/lib/firmware/amdgpu
install -m644 amdgpu/* %{buildroot}/lib/firmware/amdgpu/
install -d %{buildroot}/lib/firmware/radeon
install -m644 radeon/* %{buildroot}/lib/firmware/radeon/

%clean
rm -rf %{buildroot}

%files
%doc WHENCE
%license LICENSE.*
/lib/firmware/amdgpu/*.bin
/lib/firmware/radeon/*.bin


%changelog
* Sun Apr 25 2021 tmb <tmb> 20210423-1.mga8
+ Revision: 1719656
- amdgpu:
  * update navi10, navi14 SMC firmware
  * update arcturus, green sardine, navi10, navi12, navi14, navy flounder,
    picasso, raven, raven2, renoir, sienna cichlid, vega10, vega12, vega20
    from 21.10
- amdgpu: update navi10, navi12, navi14, picasso, raven, raven2,
  renoir, sienna cichlid, vega10, vega12, vega20 firmware for 20.50
- amdgpu: add initial support for navy flounder

* Sat Feb 13 2021 tmb <tmb> 20210211-1.mga8.nonfree
+ Revision: 1675266
- amdgpu: add initial firmware for green sardine

* Sun Dec 20 2020 tmb <tmb> 20201218-1.mga8.nonfree
+ Revision: 1661453
- update to 20201218 snapshot

* Fri Nov 20 2020 tmb <tmb> 20201118-1.mga8.nonfree
+ Revision: 1647979
- update to 20201118 (including sienna cichlid firmwares)

* Tue Oct 27 2020 luigiwalser <luigiwalser> 20201022-1.mga8.nonfree
+ Revision: 1639880
- update to 20201022 snapshot

* Wed Sep 23 2020 luigiwalser <luigiwalser> 20200918-1.mga8.nonfree
+ Revision: 1629611
- update to 20200918 snapshot

* Wed Aug 19 2020 luigiwalser <luigiwalser> 20200817-1.mga8.nonfree
+ Revision: 1615603
- update to 20200817 snapshot

* Thu Aug 06 2020 luigiwalser <luigiwalser> 20200721-2.mga8.nonfree
+ Revision: 1611542
- copy logic from kernel-firmware script to exclude free firmwares

* Thu Aug 06 2020 luigiwalser <luigiwalser> 20200721-1.mga8.nonfree
+ Revision: 1611388
- update to 20200721 snapshot
- update comments in SPEC telling how to generate tarball

* Fri Apr 17 2020 tmb <tmb> 20200416-1.mga8.nonfree
+ Revision: 1568493
- update amdgpu firmwares for 20.10

* Sat Apr 11 2020 tmb <tmb> 20200316-1.mga8.nonfree
+ Revision: 1566379
- update to 20200316 snapshot

* Fri Feb 21 2020 umeabot <umeabot> 20200204-2.mga8.nonfree
+ Revision: 1548647
- Mageia 8 Mass Rebuild

* Tue Feb 04 2020 tmb <tmb> 20200204-1.mga8.nonfree
+ Revision: 1487065
- amdgpu:
  * update to latest navi10 firmware from 19.50
  * amdgpu: add renoir firmware for 19.50
  * amdgpu: update raven2 firmware for 19.50
- radeon:
  * Revert: update oland rlc microcode from amdgpu

* Tue Jan 14 2020 tmb <tmb> 20200113-1.mga8.nonfree
+ Revision: 1477907
- amdgpu: update navi10 firmware for 19.50
- amdgpu: Add navi10 TA ucode

* Tue Jan 07 2020 tmb <tmb> 20200107-1.mga8.nonfree
+ Revision: 1477133
- amdgpu: add TA microcode for Raven asics
- amdgpu: update navi10, navi14, picasso, raven, raven2,
          vega10, vega12, vega20 for 19.50
- radeon: update oland rlc microcode from amdgpu

* Sat Dec 21 2019 tmb <tmb> 20191220-1.mga8.nonfree
+ Revision: 1469369
- update to 20191220 snapshot

* Tue Oct 08 2019 tmb <tmb> 20191008-1.mga8.nonfree
+ Revision: 1450608
- amdgpu: add initial navi14 firmware from 19.30

* Fri Sep 27 2019 tmb <tmb> 20190926-1.mga8.nonfree
+ Revision: 1447684
- amdgpu:
  * add initial navi10 firmware
  * add new raven rlc firmware
  * update picasso, raven, raven2, vega10, vega12, vega20 ucode for 19.30

* Sat Jul 20 2019 tmb <tmb> 20190720-1.mga8.nonfree
+ Revision: 1423161
- amdgpu: update picassso, polaris12, raven, raven2, vega10, vega12,
  tonga firmware to latest 19.20 firmware
- amdgpu: update picasso, raven vcn firmware, Fixes issue with stutter mode.
- amdgpu: update vega10 vce firmware, Fixes a wrap around bug during long
  encodings.

* Sat Jun 15 2019 tmb <tmb> 20190603-1.mga7.nonfree
+ Revision: 1399966
- update to 2019-06-03 snapshot

* Fri May 03 2019 tmb <tmb> 20190503-1.mga7.nonfree
+ Revision: 1396272
- amdgpu: update picasso, polaris10, polaris11, raven, raven2,
  vega10, vega12, vega20 to the latest 19.10 firmware

* Mon Apr 22 2019 tmb <tmb> 20190422-1.mga7.nonfree
+ Revision: 1394796
- update to 20190422 snapshot

* Fri Mar 15 2019 tmb <tmb> 20190314-1.mga7.nonfree
+ Revision: 1377680
- update picasso, polaris12, vega20 firmwares to latest from 18.50 branch

* Fri Feb 22 2019 tmb <tmb> 20190221-1.mga7.nonfree
+ Revision: 1369334
- amdgpu: update raven2 rlc firmware
- amdgpu: drop raven2_sdma1.bin

* Tue Feb 12 2019 tmb <tmb> 20190212-1.mga7.nonfree
+ Revision: 1366255
- amdgpu: add firmware for vega20 from 18.50

* Mon Jan 14 2019 tmb <tmb> 20190114-1.mga7.nonfree
+ Revision: 1356838
- amdgpu: add Raven2 and Picasso firmware

* Wed Dec 19 2018 tmb <tmb> 20181218-1.mga7.nonfree
+ Revision: 1342854
- Revert "amdgpu: update vega10 fw for 18.50 release" as it causes
  GPU hangs for some users

* Sat Dec 15 2018 tmb <tmb> 20181213-1.mga7.nonfree
+ Revision: 1341533
- amdgpu: update polaris, raven, vega firmware

* Fri Dec 07 2018 tmb <tmb> 20181203-1.mga7.nonfree
+ Revision: 1338854
- add new polaris _k mc firmwares

* Wed Nov 28 2018 tmb <tmb> 20181026-2.mga7.nonfree
+ Revision: 1336581
- stop rebuilding initrds on package install
- stop altering kms boot as radeon/amdgpu are now kms-only

* Wed Nov 28 2018 tmb <tmb> 20181026-1.mga7.nonfree
+ Revision: 1336560
- update to 2018-10-26 snapshot

* Fri Sep 21 2018 umeabot <umeabot> 20180710-2.mga7.nonfree
+ Revision: 1290706
- Mageia 7 Mass Rebuild

* Tue Jul 17 2018 tmb <tmb> 20180710-1.mga7.nonfree
+ Revision: 1243999
- amdgpu: sync up vega10, raven, polaris10/11/12, verde, pitcairn, tahiti,
  oland, hainan, kaveri, mullins, kabini, hawaii, bonaire firmwares with
  Amd 18.20 release

* Sun Jul 08 2018 tmb <tmb> 20180606-1.mga7.nonfree
+ Revision: 1242682
- update to 2018-06-06 snapshot

* Sat May 19 2018 tmb <tmb> 20180518-1.mga7.nonfree
+ Revision: 1230552
- update Polaris10, Polaris11, Polaris12, Vega10, Carrizo, Topaz, Stone,
  Tonga, Fiji, Raven firmwares

* Mon Apr 30 2018 tmb <tmb> 20180409-1.mga7.nonfree
+ Revision: 1224041
- amdgpu: update vce firmware for Polaris

* Sat Feb 17 2018 tmb <tmb> 20180211-1.mga7.nonfree
+ Revision: 1202147
- update to 2018-02-11 snapshot

* Sun Jan 21 2018 tmb <tmb> 20180118-1.mga7.nonfree
+ Revision: 1195557
- amdgpu: update vce firmware for Fiji
- amdgpu: update vcn firmware for raven
- amdgpu: update uvd firmware for polaris asics
- amdgpu: update vce and uvd firmware for Vega10

* Tue Dec 05 2017 tmb <tmb> 20171205-1.mga7.nonfree
+ Revision: 1181409
- add Raven firmware

* Sun Nov 26 2017 tmb <tmb> 20171123-1.mga7.nonfree
+ Revision: 1179642
- update to 2017-11-23 snapshot

* Sun Oct 15 2017 tmb <tmb> 20171009-1.mga7.nonfree
+ Revision: 1172185
- add vega10 firmwares

* Mon Jun 05 2017 tmb <tmb> 20170531-1.mga6.nonfree
+ Revision: 1106770
- update to 2017-05-31 snapshot

* Thu Feb 23 2017 tmb <tmb> 20170223-1.mga6.nonfree
+ Revision: 1087541
- amdgpu: add smc firmware for new polaris variants
- Revert "amdgpu: update VI smc/mc firmware"
- Revert "amdgpu: update VI gfx/sdma firmware"

* Tue Feb 21 2017 tmb <tmb> 20170217-1.mga6.nonfree
+ Revision: 1087241
- update to 2017-02-17 snapshot
  * radeon: add new firmware for SI chips
  * amdgpu: add firmware for polaris12 asics
  * amdgpu: update VI gfx/sdma firmware
  * amdgpu: update VI smc/mc firmware

* Sun Jan 15 2017 tmb <tmb> 20170113-1.mga6.nonfree
+ Revision: 1081816
- update to 20170113 snapshot

* Sun Jan 01 2017 tmb <tmb> 20170101-1.mga6.nonfree
+ Revision: 1079382
- update to 20170101 snapshot

* Sat Nov 26 2016 tmb <tmb> 20161028-1.mga6.nonfree
+ Revision: 1070336
- amdgpu: add new smc firmware for newer tonga and iceland chips

* Fri Oct 07 2016 tmb <tmb> 20160927-1.mga6.nonfree
+ Revision: 1059447
- amdgpu: update SMC firmware for VI parts
- radeon: update SMC firmware for CI, SI parts

* Sat Sep 24 2016 tmb <tmb> 20160920-1.mga6.nonfree
+ Revision: 1055872
- amdgpu: update tonga and fiji VCE firmware to 52.8.3

* Tue Sep 20 2016 tmb <tmb> 20160914-1.mga6.nonfree
+ Revision: 1054762
- amdgpu: update UVD firmware for VI devices

* Sat Jul 30 2016 tmb <tmb> 20160729-1.mga6.nonfree
+ Revision: 1043963
- amdgpu: update stoney UVD firmware

* Wed Jul 20 2016 tmb <tmb> 20160712-1.mga6.nonfree
+ Revision: 1042798
- update to 2016-07-12 snapshot

* Tue Jul 05 2016 tmb <tmb> 20160629-1.mga6.nonfree
+ Revision: 1038857
- update polaris firmware

* Sun Jun 19 2016 tmb <tmb> 20160608-1.mga6.nonfree
+ Revision: 1036779
- update to 20160608 snapshot

* Thu May 19 2016 tmb <tmb> 20160516-1.mga6.nonfree
+ Revision: 1016884
- update amdgpu firmware

* Fri Apr 29 2016 tmb <tmb> 20160429-1.mga6.nonfree
+ Revision: 1007945
- radeon: update CIK UVD firmware

* Tue Apr 26 2016 tmb <tmb> 20160421-1.mga6.nonfree
+ Revision: 1006294
- amdgpu: update CZ to new UVD fw that supports 40 sessions

* Sat Apr 09 2016 tmb <tmb> 20160409-1.mga6.nonfree
+ Revision: 999878
- radeon:
  * update bonaire, hawaii, kabini, kaveri, mullins firmwares
- amdgpu:
  * update carrizo, fiji, stoney, tonga, topaz firmwares
  * add polaris10 and polaris11 firmwares

* Thu Mar 03 2016 tmb <tmb> 20160219-1.mga6.nonfree
+ Revision: 984602
- update to 2016-02-19 snapshot

* Sat Nov 21 2015 tmb <tmb> 20151120-1.mga6.nonfree
+ Revision: 904767
- amdgpu:
  * update carrizo, fiji, tonga firmwares
  * add stoney firmware
- radeon:
  * update bonaire, hawaii, kabini, kaveri, mullins firmwares,
    adding sdma1, uvd, vce support

* Thu Sep 17 2015 tmb <tmb> 20150824-1.mga6.nonfree
+ Revision: 880122
- amdgpu: add firmware for VI asics

* Tue Aug 04 2015 tmb <tmb> 20150722-1.mga6.nonfree
+ Revision: 861087
- add Tahiti vce firmware

* Wed Mar 18 2015 tmb <tmb> 20150314-1.mga5.nonfree
+ Revision: 818807
- Update Kaveri MEC firmware to #396

* Wed Feb 04 2015 tmb <tmb> 20150204-1.mga5.nonfree
+ Revision: 813475
- update kaveri firmware for amdkfd support

* Mon Dec 01 2014 tmb <tmb> 20141106-1.mga5.nonfree
+ Revision: 800159
- update to 20141106

* Wed Oct 15 2014 umeabot <umeabot> 20140828-3.mga5.nonfree
+ Revision: 741394
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 20140828-2.mga5.nonfree
+ Revision: 688600
- Mageia 5 Mass Rebuild

* Sat Aug 30 2014 tmb <tmb> 20140828-1.mga5.nonfree
+ Revision: 669498
- update to 2014-08-28

* Wed Jun 04 2014 tmb <tmb> 20140603-1.mga5.nonfree
+ Revision: 632985
- update to 2014-06-03

* Fri Jan 24 2014 tmb <tmb> 20140119-1.mga4.nonfree
+ Revision: 567733
- add ucode for HAWAII GPUs

* Mon Oct 14 2013 tmb <tmb> 20131013-1.mga4.nonfree
+ Revision: 497310
- add KAVERI firmware and BONAIRE smc code

* Thu Aug 01 2013 tmb <tmb> 20130626-2.mga4.nonfree
+ Revision: 462253
- require drakxtools-backend and drakx-kbd-mouse-x11 for post(un) scripts (mga #10667)

* Sun Jul 21 2013 tmb <tmb> 20130626-1.mga4.nonfree
+ Revision: 456872
- add *_smc.bin firmwares
- add BONAIRE and KABINI firmwares

* Tue Jul 09 2013 tmb <tmb> 20130624-1.mga4.nonfree
+ Revision: 452092
- add HAINAN firmwares
- add UVD firmwares for CYPRESS, SUMO, RV710, TAHITI
- update RLC firmware to cope with UVD for ARUBA, BTC, CAYMAN, CEDAR,
  CYPRESS, JUNIPER, PITCAIRN, R700, REDWOOD, SUMO, TAHITI, VERDE

* Wed Apr 24 2013 tmb <tmb> 20130421-1.mga3.nonfree
+ Revision: 411074
- add oland firmwares

* Tue Feb 19 2013 tmb <tmb> 20120322-5.mga3.nonfree
+ Revision: 399309
- dont regenerate initrd when in installer mode

* Sun Jan 13 2013 umeabot <umeabot> 20120322-4.mga3.nonfree
+ Revision: 380152
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Apr 05 2012 anssi <anssi> 20120322-3.mga2.nonfree
+ Revision: 228622
- add/remove 'nokmsboot' boot option as appropriate when installing
  or uninstalling the package, depending on configured driver and
  hardware (see mga #3466)

* Thu Mar 22 2012 tmb <tmb> 20120322-2.mga2.nonfree
+ Revision: 225782
- fix conflicts against kernel-firmware(-nonfree)

* Thu Mar 22 2012 tmb <tmb> 20120322-1.mga2.nonfree
+ Revision: 225670
- add new firmwares:
  * PITCAIRN, TAHITI, VERDE (Southern Islands / HD7xxx)
  * ARUBA (trinity APU)

* Tue Mar 06 2012 tmb <tmb> 20120219-1.mga2.nonfree
+ Revision: 220090
- update to 2012-02-19 snapshot

* Mon Dec 19 2011 tmb <tmb> 20110601-4.mga2.nonfree
+ Revision: 184089
- rebuild initrds on initial install

* Tue Nov 08 2011 anssi <anssi> 20110601-3.mga2.nonfree
+ Revision: 165571
- add regular firmware for r100-r700 (moved from kernel-firmware)
- update summary, description and license tags
+ tmb <tmb>
- add SUMO + SUMO2 firmwares for llano APUs

* Mon Mar 21 2011 tmb <tmb> 20110310-1.mga1
+ Revision: 75332
- Obsolete radeon-rlc-firmware
- Conflict old kernel-firmware-extra
- package renamed to radeon-firmware as in now carries all radeon
  firmware files previously shipped in kernel-firmware-extra
- rename spec to match package name
- rename to radeon-firmware

* Thu Mar 17 2011 tmb <tmb> 1-7.mga1
+ Revision: 73312
- add Cayman rlc firmware

* Tue Jan 25 2011 tmb <tmb> 1-6.mga1
+ Revision: 38947
- add BTC rlc firmware

* Sat Jan 15 2011 tmb <tmb> 1-5.mga1
+ Revision: 19487
- imported package radeon-rlc-firmware

